from .core import remove_config
from cmdcheatsheet.shared.models import CommandArgument, CommandDetails


class RemoveConfig(CommandDetails):
    def __init__(self):
       super().__init__(
            [ '--remove-config', '-rc'],
            'Remove a config.',
            [CommandArgument('key')])

    def handler(self, args):
        remove_config(key=args[0])



__all__ = [
    'actions',
    'alt_store_display_strategy',
    'consts',
    'core',
    'display',
    'default_display_strategy',
    'display_available_configs',
    'display_config',
    'models',
    'remove_config',
    'set_config',
    'set_config_to_default',
    'set_single_config_to_default',
    'validators',
]



from .core import update_command
from cmdcheatsheet.shared.models import Command, CommandArgument, CommandDetails


class UpdateCommand(CommandDetails):
    def __init__(self):
       super().__init__(
            ['--update', '-u'],
            'Update a <command> by id.',
            [CommandArgument('id'), CommandArgument('name'), CommandArgument('description')])

    def handler(self, args):
        command = Command(id=int(args[0]), command=args[1], description=args[2])
        update_command(command)




from .display import display_error

def show_invalid_store_location_message():
    display_error("Something is wrong with your JSON file. The issue might appear due to the following:\n" +
          "1. The file location is wrong.\n" +
          "2. The file content is not a list of commands.")
